summaryrefslogtreecommitdiff
path: root/src/dumm/guest.h
diff options
context:
space:
mode:
authorRene Mayrhofer <rene@mayrhofer.eu.org>2010-11-28 11:42:20 +0000
committerRene Mayrhofer <rene@mayrhofer.eu.org>2010-11-28 11:42:20 +0000
commitf73fba54dc8b30c6482e1e8abf15bbf455592fcd (patch)
treea449515607c5e51a5c703d7a9b1149c9e4a11560 /src/dumm/guest.h
parentb8064f4099997a9e2179f3ad4ace605f5ccac3a1 (diff)
downloadvyos-strongswan-f73fba54dc8b30c6482e1e8abf15bbf455592fcd.tar.gz
vyos-strongswan-f73fba54dc8b30c6482e1e8abf15bbf455592fcd.zip
[svn-upgrade] new version strongswan (4.5.0)
Diffstat (limited to 'src/dumm/guest.h')
-rw-r--r--src/dumm/guest.h25
1 files changed, 20 insertions, 5 deletions
diff --git a/src/dumm/guest.h b/src/dumm/guest.h
index 5f812f8eb..789f2310e 100644
--- a/src/dumm/guest.h
+++ b/src/dumm/guest.h
@@ -1,5 +1,5 @@
/*
- * Copyright (C) 2008 Tobias Brunner
+ * Copyright (C) 2008-2009 Tobias Brunner
* Copyright (C) 2007 Martin Willi
* Hochschule fuer Technik Rapperswil
*
@@ -134,12 +134,27 @@ struct guest_t {
enumerator_t* (*create_iface_enumerator)(guest_t *this);
/**
- * Set the template COWFS overlay to use.
+ * Adds a COWFS overlay. The directory is created if it does not exist.
*
* @param parent parent directory where template diff should point to
* @return FALSE if failed
*/
- bool (*load_template)(guest_t *this, char *parent);
+ bool (*add_overlay)(guest_t *this, char *dir);
+
+ /**
+ * Removes the specified COWFS overlay.
+ *
+ * @param dir directory where overlay diff points to
+ * @return FALSE, if no found
+ */
+ bool (*del_overlay)(guest_t *this, char *dir);
+
+ /**
+ * Removes the latest COWFS overlay.
+ *
+ * @return FALSE, if no overlay was found
+ */
+ bool (*pop_overlay)(guest_t *this);
/**
* Execute a command on the guests mconsole.
@@ -134,12 +134,27 @@ struct guest_t {
*
- * @param parent parent directory where template diff should point to
- * @return FALSE if failed
+ * @param dir directory where overlay diff should point to
+ * @return FALSE, if failed
*/